package Acme::Blarghy::McBlarghBlargh;

=head1 NAME

Acme::Blarghy::McBlarghBlargh

Blarghing the Blarghing world since 20blarghyBLARGH.

=head1 SYNOPSIS

    sudo blarghymcblarghblargh

=head1 DESCRIPTION

run the above command. Receive bacon. Also, teh lulz.

=head1 SEE ALSO

L<http://www.blarghymcblarghblargh.com>
L<http://github.com/dhoss/acmeblarghymcblarghblargh/tree/master>


=head1 AUTHOR

Devin Austin
L<http://www.codedright.net>
L<mailto:dhoss@cpan.org>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut


use Moose;

our $VERSION = '0.0022';

## here we do stuff.

use Net::Twitter;     # does nothing yet

sub blargh { "BLARRRRRRGH. How much of it is in your life today?\n"; }

1;
